CrontabTimer

Struct CrontabTimer 

pub struct CrontabTimer {
    pub minutes: Vec<CrontabValue>,
    pub hours: Vec<CrontabValue>,
    pub days: Vec<CrontabValue>,
    pub months: Vec<CrontabValue>,
    pub dows: Vec<CrontabValue>,
}
A crontab timer is a set of crontab values for each field (minutes, hours, days, months, days of week)

Fields

minutes: Vec<CrontabValue>hours: Vec<CrontabValue>days: Vec<CrontabValue>months: Vec<CrontabValue>dows: Vec<CrontabValue>

Days of week

Implementations

Source

impl CrontabTimer

pub fn minutes(&self) -> &Vec<CrontabValue>

pub fn hours(&self) -> &Vec<CrontabValue>

pub fn days(&self) -> &Vec<CrontabValue>

pub fn months(&self) -> &Vec<CrontabValue>

pub fn dows(&self) -> &Vec<CrontabValue>

Days of week

Source

impl CrontabTimer

pub fn every_minute() -> CrontabTimer

Run every minute.

pub fn every_n_minutes(step: u32) -> Result<CrontabTimer, CrontabTimerError>

Run every step minutes.

pub fn hourly_at(minute: u32) -> Result<CrontabTimer, CrontabTimerError>

Run once per hour at the given minute.

pub fn daily_at( hour: u32, minute: u32, ) -> Result<CrontabTimer, CrontabTimerError>

Run once per day at the given UTC hour and minute.

pub fn weekly_on( weekday: Weekday, hour: u32, minute: u32, ) -> Result<CrontabTimer, CrontabTimerError>

Run once per week on the given weekday, UTC hour and minute.

pub fn monthly_on( day: u32, hour: u32, minute: u32, ) -> Result<CrontabTimer, CrontabTimerError>

Run once per month on the given day, UTC hour and minute.

pub fn yearly_on( month: u32, day: u32, hour: u32, minute: u32, ) -> Result<CrontabTimer, CrontabTimerError>

Run once per year on the given month, day, UTC hour and minute.

pub fn should_run_at(&self, at: &NaiveDateTime) -> bool

Check if the timer should run at specifed date

use graphile_worker_crontab_types::{CrontabValue, CrontabTimer};

let crontab_timer = CrontabTimer {
    minutes: vec![CrontabValue::Number(30)],
    hours: vec![CrontabValue::Range(8, 10)],
    days: vec![CrontabValue::Step(4)],
    ..Default::default()
};
assert!(crontab_timer.should_run_at(&"2012-12-17T08:30:12".parse().unwrap()));
assert!(crontab_timer.should_run_at(&"2015-02-05T09:30:00".parse().unwrap()));
assert!(crontab_timer.should_run_at(&"1998-10-13T10:30:59".parse().unwrap()));

assert!(!crontab_timer.should_run_at(&"2012-12-17T11:30:59".parse().unwrap()));
assert!(!crontab_timer.should_run_at(&"2015-02-05T09:31:00".parse().unwrap()));