pub struct CronBuilder<T: TaskHandler> { /* private fields */ }Expand description
Builder for a typed cron entry.
Implementations
Sourceimpl<T: TaskHandler> CronBuilder<T>
impl<T: TaskHandler> CronBuilder<T>
Sourcepub fn new(timer: CrontabTimer) -> Self
pub fn new(timer: CrontabTimer) -> Self
Build a typed cron entry from a custom timer.
Sourcepub fn id(self, id: impl Into<String>) -> Self
pub fn id(self, id: impl Into<String>) -> Self
Set a stable identifier for this cron entry.
Use this when more than one schedule targets the same task.
Sourcepub fn fill(self, fill: CrontabFill) -> Self
pub fn fill(self, fill: CrontabFill) -> Self
Backfill missed executions for the given duration.
Sourcepub fn max_attempts(self, max_attempts: u16) -> Self
pub fn max_attempts(self, max_attempts: u16) -> Self
Override the maximum number of attempts for jobs created by this cron.
Sourcepub fn queue(self, queue: impl Into<String>) -> Self
pub fn queue(self, queue: impl Into<String>) -> Self
Add jobs created by this cron to a named queue.
Sourcepub fn priority(self, priority: i16) -> Self
pub fn priority(self, priority: i16) -> Self
Override the priority for jobs created by this cron.
Sourcepub fn job_key_mode(self, job_key_mode: JobKeyMode) -> Self
pub fn job_key_mode(self, job_key_mode: JobKeyMode) -> Self
Set the behavior for an existing job with the same job key.
Sourcepub fn payload(self, payload: T) -> Result<Self, Error>
pub fn payload(self, payload: T) -> Result<Self, Error>
Serialize a typed task payload for jobs created by this cron.
Sourcepub fn payload_value(self, payload: impl Into<Value>) -> Self
pub fn payload_value(self, payload: impl Into<Value>) -> Self
Set a pre-built JSON payload for jobs created by this cron.